@@ -73,6 +73,9 @@ MAX_CONFIG_DRIVE_SIZE_MB = 64
 # Maximum disk size supported by MBR is 2TB (2 * 1024 * 1024 MB)
 MAX_DISK_SIZE_MB_SUPPORTED_BY_MBR = 2097152
 
+# Limit the memory address space to 1 GiB when running qemu-img
+QEMU_IMG_LIMITS = processutils.ProcessLimits(address_space=1 * units.Gi)
+
 
 def list_partitions(device):
     """Get partitions information from given device.
@@ -291,14 +294,15 @@ def qemu_img_info(path):
         return imageutils.QemuImgInfo()
 
     out, err = utils.execute('env', 'LC_ALL=C', 'LANG=C',
-                             'qemu-img', 'info', path)
+                             'qemu-img', 'info', path,
+                             prlimit=QEMU_IMG_LIMITS)
     return imageutils.QemuImgInfo(out)
 
 
 def convert_image(source, dest, out_format, run_as_root=False):
     """Convert image to other format."""
     cmd = ('qemu-img', 'convert', '-O', out_format, source, dest)
-    utils.execute(*cmd, run_as_root=run_as_root)
+    utils.execute(*cmd, run_as_root=run_as_root, prlimit=QEMU_IMG_LIMITS)
 
 
 def populate_image(src, dst):
